@@ -15,11 +15,13 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 from contextlib import contextmanager
 from copy import copy
 from logging import DEBUG, ERROR, INFO, WARNING
-from typing import Any, Callable, Dict, Generator, Optional
+from typing import Any, Callable, Generator
+from warnings import warn
 from weakref import WeakKeyDictionary
 
 from pypsrp.host import PSHost
@@ -75,18 +77,18 @@ class PsrpHook(BaseHook):
 
     _conn = None
     _configuration_name = None
-    _wsman_ref: "WeakKeyDictionary[RunspacePool, WSMan]" = WeakKeyDictionary()
+    _wsman_ref: WeakKeyDictionary[RunspacePool, WSMan] = WeakKeyDictionary()
 
     def __init__(
         self,
         psrp_conn_id: str,
         logging_level: int = DEBUG,
-        operation_timeout: Optional[int] = None,
-        runspace_options: Optional[Dict[str, Any]] = None,
-        wsman_options: Optional[Dict[str, Any]] = None,
-        on_output_callback: Optional[OutputCallback] = None,
+        operation_timeout: int | None = None,
+        runspace_options: dict[str, Any] | None = None,
+        wsman_options: dict[str, Any] | None = None,
+        on_output_callback: OutputCallback | None = None,
         exchange_keys: bool = True,
-        host: Optional[PSHost] = None,
+        host: PSHost | None = None,
     ):
         self.conn_id = psrp_conn_id
         self._logging_level = logging_level
@@ -214,11 +216,33 @@ class PsrpHook(BaseHook):
             if local_context:
                 self.__exit__(None, None, None)
 
-    def invoke_cmdlet(self, name: str, use_local_scope=None, **parameters: Dict[str, str]) -> PowerShell:
+    def invoke_cmdlet(
+        self,
+        name: str,
+        use_local_scope: bool | None = None,
+        arguments: list[str] | None = None,
+        parameters: dict[str, str] | None = None,
+        **kwargs: str,
+    ) -> PowerShell:
         """Invoke a PowerShell cmdlet and return session."""
+        if kwargs:
+            if parameters:
+                raise ValueError("**kwargs not allowed when 'parameters' is used at the same time.")
+            warn(
+                "Passing **kwargs to 'invoke_cmdlet' is deprecated "
+                "and will be removed in a future release. Please use 'parameters' "
+                "instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            parameters = kwargs
+
         with self.invoke() as ps:
             ps.add_cmdlet(name, use_local_scope=use_local_scope)
-            ps.add_parameters(parameters)
+            for argument in arguments or ():
+                ps.add_argument(argument)
+            if parameters:
+                ps.add_parameters(parameters)
         return ps
 
     def invoke_powershell(self, script: str) -> PowerShell:
@@ -232,7 +256,7 @@ class PsrpHook(BaseHook):
         if message_type == MessageType.ERROR_RECORD:
             log(INFO, "%s: %s", record.reason, record)
             if record.script_stacktrace:
-                for trace in record.script_stacktrace.split('\r\n'):
+                for trace in record.script_stacktrace.split("\r\n"):
                     log(INFO, trace)
 
         level = INFORMATIONAL_RECORD_LEVEL_MAP.get(message_type)
